@@ -92,6 +92,7 @@ QJsonObject ConfigSerializer::serializeOutput(const OutputPtr &output)
     obj[QLatin1String("clones")] = serializeList(output->clones());
     //obj[QLatin1String("edid")] = output->edid()->raw();
     obj[QLatin1String("sizeMM")] = serializeSize(output->sizeMm());
+    obj[QLatin1String("replicationSource")] = output->replicationSource();
 
     QJsonArray modes;
     Q_FOREACH (const ModePtr &mode, output->modes()) {
@@ -136,9 +137,9 @@ QPoint ConfigSerializer::deserializePoint(const QDBusArgument &arg)
         QVariant value;
         arg.beginMapEntry();
         arg >> key >> value;
-        if (key == QLatin1String("x")) {
+        if (key == QLatin1Char('x')) {
             x = value.toInt();
-        } else if (key == QLatin1String("y")) {
+        } else if (key == QLatin1Char('y')) {
             y = value.toInt();
         } else {
             qCWarning(KSCREEN) << "Invalid key in Point map: " << key;
@@ -178,11 +179,11 @@ ConfigPtr ConfigSerializer::deserializeConfig(const QVariantMap &map)
 {
     ConfigPtr config(new Config);
 
-    if (map.contains(QStringLiteral("features"))) {
+    if (map.contains(QLatin1String("features"))) {
         config->setSupportedFeatures(static_cast<Config::Features>(map[QStringLiteral("features")].toInt()));
     }
 
-    if (map.contains(QStringLiteral("outputs"))) {
+    if (map.contains(QLatin1String("outputs"))) {
         const QDBusArgument &outputsArg = map[QStringLiteral("outputs")].value<QDBusArgument>();
         outputsArg.beginArray();
         OutputList outputs;
@@ -199,7 +200,7 @@ ConfigPtr ConfigSerializer::deserializeConfig(const QVariantMap &map)
         config->setOutputs(outputs);
     }
 
-    if (map.contains(QStringLiteral("screen"))) {
+    if (map.contains(QLatin1String("screen"))) {
         const QDBusArgument &screenArg = map[QStringLiteral("screen")].value<QDBusArgument>();
         const KScreen::ScreenPtr screen = deserializeScreen(screenArg);
         if (!screen) {
@@ -251,6 +252,8 @@ OutputPtr ConfigSerializer::deserializeOutput(const QDBusArgument &arg)
             output->setPrimary(value.toBool());
         } else if (key == QLatin1String("clones")) {
             output->setClones(deserializeList<int>(value.value<QDBusArgument>()));
+        } else if (key == QLatin1String("replicationSource")) {
+            output->setReplicationSource(value.toInt());
         } else if (key == QLatin1String("sizeMM")) {
             output->setSizeMm(deserializeSize(value.value<QDBusArgument>()));
         } else if (key == QLatin1String("modes")) {
